@@ -1,12 +1,14 @@
 package Config::IOD::Expr;
 
-our $DATE = '2021-06-23'; # DATE
-our $VERSION = '0.343'; # VERSION
-
 use 5.010;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-05-02'; # DATE
+our $DIST = 'Config-IOD-Reader'; # DIST
+our $VERSION = '0.344'; # VERSION
+
 my $EXPR_RE = qr{
 
 (?&ANSWER)
@@ -77,7 +79,7 @@ sub _parse_expr {
     my $str = shift;
 
     return [400, 'Not a valid expr'] unless $str =~ m{\A$EXPR_RE\z}o;
-    my $res = eval "package Config::IOD::Expr::_Compiled; no strict; no warnings; $str";
+    my $res = eval "package Config::IOD::Expr::_Compiled; no strict; no warnings; $str"; ## no critic: BuiltinFunctions::ProhibitStringyEval
     return [500, "Died when evaluating expr: $@"] if $@;
     [200, "OK", $res];
 }
@@ -97,7 +99,7 @@ Config::IOD::Expr - Parse expression
 
 =head1 VERSION
 
-This document describes version 0.343 of Config::IOD::Expr (from Perl distribution Config-IOD-Reader), released on 2021-06-23.
+This document describes version 0.344 of Config::IOD::Expr (from Perl distribution Config-IOD-Reader), released on 2022-05-02.
 
 =head1 SYNOPSIS
 
@@ -111,6 +113,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 Source repository is at L<https://github.com/perlancar/perl-Config-IOD-Reader>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2021, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Config-IOD-Reader>
@@ -119,15 +149,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
